# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

from ionas.request import Request, Entry, XmlNode
from product_conf import STOR_IF_TO_VOL
from fal_info import Results
from iobase.cmdexec import (CmdExec, PIPE, NULL)
from product_conf import SUDO_CMD
from fal_info import FAL_VOLCTRL_PATH, ReqTypes
import os
import time
from datetime import datetime

class AutoRemove():
    VOLUME = STOR_IF_TO_VOL
    
    def query(self, volume=VOLUME['internal'][1], to_dict=True):
        def _to_dict(entry):
            dict_ = {}
            try:
                vol = entry.get().get_node('volume')
                dict_['size'] = {}  # bytes
                dict_['size']['total'] = int(vol.get_value('capacity/total', 0))
                dict_['size']['use'] = int(vol.get_value('capacity/use', 0))
                dict_['mountdst'] = vol.get_value('mountdst', None)
                dict_['status'] = vol.get_value('status', None)
                dict_['filesystem'] = vol.get_value('filesystem', None)
                dict_['encrypt'] = vol.get_node('filesystem').is_set_to_true('encrypt')
            except:
                pass
            return dict_
        
        request = Request(FAL_VOLCTRL_PATH, filter_cmd=SUDO_CMD)
        entry = Entry(ReqTypes.QUERY, """<volctrl>
            <volume>
                <name type="volume">%s</name>
            </volume>
        </volctrl>""" % volume)
        
        response = request.request(entry)
        res_entry = response.get_entrylist().get_entry()
        self.__query_cache = _to_dict(res_entry)
        return self.__query_cache if to_dict else entry

if __name__ == '__main__':
    {{ enabled }}
    aobj = AutoRemove()
    aval = aobj.query()
    volspaceused = float(aval['size']['use'])
    volspacetotal = float(aval['size']['total'])
    
    if volspacetotal == 0:
        percent = 100
    else:
        percent = volspaceused / volspacetotal
    
    if percent < float({{ percent }}):
        now = int(time.mktime(datetime.now().timetuple()))
        
        # remove old log
        for root, dirs, files in os.walk("/mnt/sataraid1/share/LAN DISK Log/SysLogServer/"):
            for file in files:
                path = os.path.join(root, file)
                mtime = os.stat(path).st_mtime
                diff = now - mtime
                if diff > {{ days }} * 24 * 60 * 60:
                    os.remove(path)
