# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from django import forms
import os
import re
from project.view import FuncView
import settings

from project.forms.fields.checkbox import CheckboxField
from django.forms import IntegerField

from fields import SaveSyslogCheckboxField
from fields import AutoDeleteSyslogFileCheckboxField
from fields import RemainingCapacityForSyslogTextField
from fields import PeriodForSyslogTextField
from fields import LogSizeForSyslogTextField

from project.fal.syslogsrv import FALSyslogSrv, FACILITIES, PRIORITIES
from systemlog import FALSystemlog


class ConfForm(forms.Form):
   
    syslog_enabled = SaveSyslogCheckboxField()
    syslog_auto_delete = AutoDeleteSyslogFileCheckboxField()
    syslog_remaining_capacity = RemainingCapacityForSyslogTextField()
    syslog_period = PeriodForSyslogTextField()
    size = LogSizeForSyslogTextField()

    def __init__(self, *args, **kwargs):
        super(ConfForm, self).__init__(*args, **kwargs)

        self.fields["udp"] = IntegerField(label=_(u"syslogsrv: syslog udp port number"))
        self.fields["tcp"] = IntegerField(label=_(u"syslogsrv: syslog tcp port number"))


class ConfView(FuncView):

    views = ['apply']

    def view(self, request):
        form = ConfForm(initial=self.__initial())

        template = os.path.join(self.TEMPLATES, 'template.html')
        dictionary = {
            'form': form,
        }
        return {
            self.KEY_TEMPLATE: template,
            self.KEY_TEMPLATE_DIC: dictionary,
        }

    def view_apply(self, request):
        form = ConfForm(data=request.POST)

        with self.processing() as p:
            p.break_if_state_change()
            if form.is_valid():
                result = True

                syslogsrv = FALSyslogSrv()
                if syslogsrv.apply({
                    "settings": {
                        "enabled": form.cleaned_data["syslog_enabled"],
                        "udp": form.cleaned_data["udp"],
                        "tcp": form.cleaned_data["tcp"],
                        "size": form.cleaned_data["size"],
                        "autodelete": {
                            "enabled": form.cleaned_data["syslog_auto_delete"],
                            "expire": {
                                "days": form.cleaned_data["syslog_period"],
                                "percent": form.cleaned_data["syslog_remaining_capacity"],
                            },
                        },
                    },
                }):
                    self.set_message(syslogsrv.get_message())
                    result = True
                else:
                    self.set_message(syslogsrv.get_message())
                    result = False

                p.result(result)

        template = os.path.join(self.TEMPLATES, 'template.html')
        dictionary = {
            'form': form,
        }
        return {
            self.KEY_TEMPLATE: template,
            self.KEY_TEMPLATE_DIC: dictionary,
        }

    def __initial(self):
        try:
            data = FALSyslogSrv().load()
            return {
                "udp": data["settings"]["udp"],
                "tcp": data["settings"]["tcp"],
                "size": data["settings"]["size"],
                "syslog_enabled": data["settings"]["enabled"],
                "syslog_auto_delete": data["settings"]["autodelete"]["enabled"],
                "syslog_remaining_capacity": data["settings"]["autodelete"]["expire"]["percent"],
                "syslog_period": data["settings"]["autodelete"]["expire"]["days"],
            }
        except:
            return {}
